package src;


import java.io.BufferedReader;
import java.io.FileInputStream;
import java.io.FileNotFoundException;
import java.io.FileWriter;
import java.io.IOException;
import java.io.InputStreamReader;
import java.io.PrintWriter;
import java.util.Vector;

/**
 * Classe simple qui lit un fichier en entree ligne par ligne
 *  et reecrit son contenu un mot par ligne.
 * Les lignes commenant par % sont ignorees.
 * @author jroyer
 * @date 8/07/2008
 */
public class Loader {
	
	/** constantes pour les suffixes entree. */
	private static String IN = ".idx";
	
	/** suffixe pour fichier de sortie. */
	private static String OUT = ".ind";

	/**
	 * Le nom du fichier.
	 */
	private String fileName;
	
	/**
	 * La liste des mots.
	 */
	private Vector<String> mots;
	
	/**
	 * Le constructeur.
	 * @param name le nom du fichier
	 */
	public Loader(final String name) {
		this.fileName = name;
		this.mots = new Vector<String>();
	}
	
	/**
	 * Lecture du fichier et traitement des erreurs.
	 */
	public void load() {
		try {
			FileInputStream fis = new FileInputStream(this.getFileName() + IN);
			BufferedReader br = new BufferedReader(new InputStreamReader(fis));
			this.read(br);
			// pour fermer
			br.close();
			fis.close();
		} catch (FileNotFoundException e) {
			System.err.println(" Loader.load: fichier inexistant  " + e);
		} catch (IOException e) {
			System.err.println(" Loader.load: problme de lecture " + e);
		}
	}
	
	/**
	 * Lecture des lignes et dcoupage des mots
	 * et memorisation.
	 * @param br buffer
	 */
	private void read(final BufferedReader br) {
		try {
			while (br.ready()) {
				String ligne = br.readLine();
				// oublie les lignes vides et les commentaires commencant par '%'
				if ((ligne.length() != 0) && (ligne.charAt(0) != '%')) {
					// decoupage en mots
					String[] tokens = ligne.split(" ");
					// memorisation des mots
					for (int i = 0; i < tokens.length; i++) {
						this.getMots().add(tokens[i]);
					}
				}
			}
		} catch (IOException e) {
			System.err.println(" Loader.read: problme de lecture  " + e);
		}
	}
	
	/**
	 * Ecriture d'une chaine dans le fichier
	 * de sortie.
	 * @param str la chaine a memoriser
	 */
	public void output(final String str) {
		FileWriter fos;
		PrintWriter f;
		try {
			fos = new FileWriter(this.getFileName() + OUT);
			f = new PrintWriter(fos);
			// entete
			f.println("% fichier des mots de " + this.getFileName());
			// ecriture
			f.println(str);
			f.close();
		} catch (Exception e) {
			System.out.println("Loader.output: fichier alerte " + e);
		}
	}
	
	/**
	 * Representation sous forme de chaine.
	 * @return string
	 */
	public String toString() {
		String result = "";
		for (String str : this.getMots()) {
			result += str + "\n";
		}
		return result;
	}

	/**
	 * @return the fileName
	 */
	public String getFileName() {
		return fileName;
	}

	/**
	 * @param name the file name to set
	 */
	public void setFileName(final String name) {
		this.fileName = name;
	}

	/**
	 * @return the mots
	 */
	public Vector<String> getMots() {
		return mots;
	}

	/**
	 * @param mots the mots to set
	 */
	public void setMots(Vector<String> mots) {
		this.mots = mots;
	}

}
